@@ -6,11 +6,12 @@ use Archive::Libarchive 0.03 qw( ARCHIVE_OK ARCHIVE_WARN ARCHIVE_EOF );
 use Ref::Util qw( is_plain_coderef is_plain_arrayref is_plain_scalarref is_ref );
 use Carp ();
 use Path::Tiny ();
-use 5.022;
-use experimental qw( signatures refaliasing postderef );
+use 5.020;
+use Alias::Any;
+use experimental qw( signatures postderef );
 
 # ABSTRACT: Peek into archives without extracting them
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 sub new ($class, %options)
@@ -202,7 +203,7 @@ sub as_hash ($self)
     {
       if(defined $hash{$target})
       {
-        \$hash{$path} = \$hash{$target};
+        alias $hash{$path} = $hash{$target};
       }
       else
       {
@@ -256,7 +257,7 @@ Archive::Libarchive::Peek - Peek into archives without extracting them
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -415,7 +416,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Graham Ollis.
+This software is copyright (c) 2021-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
